#!/usr/bin/perl
# ACME Ordering sample application (c) - 2001, Eastwright Corp.
# Release 1.00
# Go to http://www.eastwright.com/internet/aoladdons/ for latest release
#

use strict;
require 5.003;
use FindBin;
use lib $FindBin::Bin;
if ($ENV{'WINDIR'} ne undef) {
  chdir($FindBin::Bin);
}
use aolapi;

# NOTE: onreceipt scripts always being called by Accounts Online in relay mode
# that is
# 1) Customer will not see actual url of the script (no need in pin based verification)
# 2) Html header already printed by Accounts Online. You can uncomment the line below
# only for standalone debugging

#print "Content-type: text/html\n\n";

# parsing inputs

my %INPUT;
my $buffer = <STDIN>;
my @pairs = split(/&/, $buffer);
foreach my $pair (@pairs) {
  my ($name, $value) = split(/=/, $pair);
  $value =~ s/%0D%0A/\n/g;
  $value =~ s/%0A%0D/\n/g;
  $value =~ tr/+/ /;
  $value =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
  if ($INPUT{$name}) { $INPUT{$name} = $INPUT{$name}.",".$value; }
  else { $INPUT{$name} = $value; }
}

# printing header - apply changes header() and footer() functions at the bottom
# in order to change payment form page appearance

header();

# Trying to initialize Accounts Online API

if (!aolapi::init()) {
  errexit("Unable to initialize Accounts Online API");
}

# preparing account and product data

my %accnt = aolapi::getaccnt($INPUT{'accid'});
if (!%accnt) {
  errexit("Failure reading account data, id=$INPUT{'accid'}, Error: " . aolapi::error());
}
my %product = aolapi::getproduct($INPUT{'prodid'});
if (!%product) {
  errexit("Failure reading product data, id=$INPUT{'prodid'}, Error: " . aolapi::error());
}

# print receipt

receipt();

# print instructions and exit

instructions();
footer();
exit;

# ====================================================================== receipt
# printing receipt

sub receipt {
  my $name = 'customer';
  $name = "$accnt{'name'} $accnt{'lname'}" if $accnt{'name'} ne undef;
  print "<br>Dear $name,<br><br>Thank you for shopping in our store.<br><br>Your order:<br>\n" .
        "<table border=1 cellspacing=3 cellpadding=3><tr><td>Description</td><td>Qty</td><td>Subtotal</td></tr>\n";
  my $itemprice = $product{'setup'};
  print "<tr><td>$product{'description'}</td><td>1</td><td>" . sprintf("%.2f", $itemprice) . "</td></tr>\n";
  my $vat = aolapi::vat($itemprice, $accnt{'id'}, $product{'id'});
  my $gst = aolapi::gst($itemprice + $vat, $accnt{'id'}, $product{'id'});
  $gst = sprintf("%.2f", $gst);
  $vat = sprintf("%.2f", $vat);
  if ($vat != 0) {
    print "<tr><td colspan=\"2\"><b>VAT</b></td><td>" .  $vat . "</td></tr>\n";
  }
  if ($gst != 0) {
    print "<tr><td colspan=\"2\"><b>Sales Tax</b></td><td>" .  $gst . "</td></tr>\n";
  }
  print "<tr><td colspan=\"2\"><b>Total</b></td><td>" . 
        sprintf("%.2f", $itemprice + $vat + $gst) .
        "</td></tr></table><br><br>\n";
}
# ================================================================= instructions

sub instructions {
print <<EOT;
<br>
Return to <a href="http://www.eastwright.com/internet/aoladdons/">Sample Applications</a>
<br><br>
<b>Notice to developer:</b> Depending on transaction gateway in use url of this page may be
not the one of your site (please review browser address line). This is why you must use
fully qualified urls here, i.e. http://www.domain.com/some_url, rather than /some_url or www.domain.com/some_url.
<br>
EOT
}

sub header() {
  print "<html><head></head><body bgcolor=#EAEAEA><center><br><br>";
}
sub footer() {
  print "</center></body></html>\n";
}
sub errexit {
  print "<br><b>$_[0]</b></br>\n";
  footer();
  exit;
}


