#!/usr/bin/perl
#
# ACME Ordering sample application (c) - 2001, Eastwright Corp.
# Release 1.00
# Go to http://www.eastwright.com/internet/aoladdons/ for latest release
#
# Limitations:
#  1) No support for non-merchant type accounts (ClickBank, iBill Complete)
#  2) No support for VAT and GST

use strict;

# The $pin variable setting must match the one as per System Setup panel

my $pin='777';

# The $prodidname variable holds id of the input, used to convey product id

my $prodidname = 'customarg1';

# The $amountname variable holds id of the input, used to convey product price
# this used in case of products with variable price

my $amountname = 'customarg3';

# end of configuration section

use FindBin;
use lib $FindBin::Bin;
if ($ENV{'WINDIR'} ne undef) {
  chdir($FindBin::Bin);
}
use aolapi;
require 5.003;

print "Content-type: text/html\n\n";

# parsing inputs

my %INPUT;
my @pairs = split(/&/, $ENV{'QUERY_STRING'});
foreach my $pair (@pairs) {
  my ($name, $value) = split(/=/, $pair);
  $value =~ tr/+/ /;
  $value =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
  if ($INPUT{$name}) { $INPUT{$name} = $INPUT{$name}.",".$value; }
  else { $INPUT{$name} = $value; }
}

# printing header - apply changes header() and footer() functions at the bottom
# in order to change payment form page appearance

header();

# verifying if the script being executed by Account Online, rather than bad guys

my $pincode = crypt($INPUT{'accid'} . $pin, 'aa');
if ($pincode ne $INPUT{'pincode'}) {
  errexit("Invalid data");
}

# Trying to initialize Accounts Online API

if (!aolapi::init()) {
  errexit("Unable to initialize Accounts Online API");
}

# print payment form and complete html page

payform();
footer();
exit;

# ====================================================================== payform

sub payform {
  my $prodid = $INPUT{$prodidname};
  if ($prodid eq undef) { errexit("Missing product id"); }
  my %product = aolapi::getproduct($prodid);
  if (!%product) { errexit("Error reading product info, prodid=$prodid"); }
  if ($product{'billtype'} ne 'N') {
    errexit("Product $product{'description'} (prodid=$prodid) is not of \"Invoice Normal\" type");
  }
  my $amount = $product{'setup'};
  if ($amount eq '*') {
    $amount = $INPUT{$amountname};
    if ($amount eq undef) {
      errexit("No transaction amount specified for variable price product $product{'description'} (prodid=$prodid)");
    }
  } elsif ($amount eq undef) {
    errexit("No setup amount specified for product $product{'description'} (prodid=$prodid)");
  }
  my $accid = $INPUT{'accid'};
  print aolapi::payform($prodid, $amount, $accid);
  footer();
  exit;
}

sub header() {
  print "<html><head></head><body bgcolor=#EAEAEA><center><br><br>";
}
sub footer() {
  print "</center></body></html>\n";
}
sub errexit {
  print "<br><b>$_[0]</b></br>\n";
  footer();
  exit;
}

